@@ -68,16 +68,19 @@ namespace giac {
   }
 
   rootmap & symbolic_rootof_list(){
-    static rootmap * ans= new rootmap;
+    static rootmap * ans= 0;
+    if (!ans) ans=new rootmap;
     return *ans;
   }
   rootmap & proot_list(){
-    static rootmap * ans= new rootmap;
+    static rootmap * ans= 0;
+    if (!ans) ans=new rootmap;
     return *ans;
   }
 
   rootmap & galoisconj_list(){
-    static rootmap * ans= new rootmap;
+    static rootmap * ans= 0;
+    if (!ans) ans=new rootmap;
     return *ans;
   }
 
@@ -147,7 +150,7 @@ namespace giac {
     return galoisconj(*g._VECTptr,contextptr);
   }
   static const char _galoisconj_s []="galoisconj";
-  static define_unary_function_eval (__galoisconj,&giac::_galoisconj,_galoisconj_s);
+  static define_unary_function_eval (__galoisconj,&_galoisconj,_galoisconj_s);
   define_unary_function_ptr5( at_galoisconj ,alias_at_galoisconj,&__galoisconj,0,true);
 
   // if true, g is a rootof such that conj(rootof(w))=g
@@ -226,7 +229,7 @@ namespace giac {
     }
     gen res;
 #ifdef SMARTPTR64
-    * ((longlong * ) &res) = longlong(new ref_algext) << 16;
+    * ((ulonglong * ) &res) = ulonglong(new ref_algext) << 16;
 #else
     res.__EXTptr=new ref_algext;
 #endif
@@ -254,7 +257,7 @@ namespace giac {
 	max_im=cur_im;
       }
       else { // same argument
-	if ( std::abs(cur_re-max_re)<eps*max_re && (cur_im>max_im) ){
+	if ( absdouble(cur_re-max_re)<eps*max_re && (cur_im>max_im) ){
 	  current=*it;
 	  max_im=cur_im;
 	}
@@ -534,6 +537,7 @@ namespace giac {
 #ifndef NO_STDEXCEPT
 		}
 		catch (std::runtime_error & ){
+		  last_evaled_argptr(contextptr)=NULL;
 		  K=0;
 		}
 #endif
@@ -576,6 +580,7 @@ namespace giac {
 #ifndef NO_STDEXCEPT
 		}
 		catch (std::runtime_error & ){
+		  last_evaled_argptr(contextptr)=NULL;
 		  K=0;
 		}
 #endif
@@ -1190,7 +1195,7 @@ namespace giac {
   partial_derivative_multiargs D_rootof(&d_rootof);
   */
   static const char _rootof_s []="rootof";
-  static define_unary_function_eval2 (__rootof,&giac::rootof,_rootof_s,&printasrootof);
+  static define_unary_function_eval2 (__rootof,&rootof,_rootof_s,&printasrootof);
   define_unary_function_ptr5( at_rootof ,alias_at_rootof,&__rootof,0,true);
 
   gen max_algext(const gen & args,GIAC_CONTEXT){
@@ -1200,7 +1205,7 @@ namespace giac {
     return MAX_ALG_EXT_ORDER_SIZE=MAX_COMMON_ALG_EXT_ORDER_SIZE=g.val;
   }
   static const char _max_algext_s []="max_algext";
-  static define_unary_function_eval (__max_algext,&giac::max_algext,_max_algext_s);
+  static define_unary_function_eval (__max_algext,&max_algext,_max_algext_s);
   define_unary_function_ptr5( at_max_algext ,alias_at_max_algext,&__max_algext,0,true);
 
   static vecteur sturm(const gen & g){
@@ -1381,7 +1386,7 @@ namespace giac {
     return sturmab(P,x,a,b,contextptr);
   }
   static const char _sturmab_s []="sturmab";
-  static define_unary_function_eval (__sturmab,&giac::_sturmab,_sturmab_s);
+  static define_unary_function_eval (__sturmab,&_sturmab,_sturmab_s);
   define_unary_function_ptr5( at_sturmab ,alias_at_sturmab,&__sturmab,0,true);
 
   gen _sturm(const gen & g,GIAC_CONTEXT){
@@ -1413,7 +1418,7 @@ namespace giac {
     return gendimerr(contextptr);
   }
   static const char _sturm_s []="sturm";
-  static define_unary_function_eval (__sturm,&giac::_sturm,_sturm_s);
+  static define_unary_function_eval (__sturm,&_sturm,_sturm_s);
   define_unary_function_ptr5( at_sturm ,alias_at_sturm,&__sturm,0,true);
 
   gen _sturmseq(const gen & g,GIAC_CONTEXT){
@@ -1422,7 +1427,7 @@ namespace giac {
     return _sturm(g,contextptr);
   }
   static const char _sturmseq_s []="sturmseq";
-  static define_unary_function_eval (__sturmseq,&giac::_sturmseq,_sturmseq_s);
+  static define_unary_function_eval (__sturmseq,&_sturmseq,_sturmseq_s);
   define_unary_function_ptr5( at_sturmseq ,alias_at_sturmseq,&__sturmseq,0,true);
 
   void recompute_minmax(const vecteur & w,const vecteur & range,const gen & expr,const gen & var,gen & resmin,gen & resmax,vecteur & xmin,vecteur & xmax,int direction,GIAC_CONTEXT){
@@ -1437,6 +1442,7 @@ namespace giac {
       try {
 	tmp=limit(expr,*var._IDNTptr,*it,direction,contextptr);
       } catch (std::runtime_error & err){
+	last_evaled_argptr(contextptr)=NULL;
 	tmp=undef;
       }
 #endif
@@ -1639,6 +1645,7 @@ namespace giac {
 	vecteur v=*g2._VECTptr;
 	if ( (v.size()==3) && (v.front()==vecteur(0) || v.front()==_DOUBLE_ || v.front()==_ZINT || v.front()==_SYMB || v.front()==0) && (v[1].type==_VECT)){
 	  a=*v[1]._VECTptr;
+	  if (v.front()==_ZINT) return 3;
 	  return 1;
 	}
 	if (v.size()==1 && v.front()==_ZINT)
@@ -1666,6 +1673,7 @@ namespace giac {
 #ifndef NO_STDEXCEPT
       }
       catch (std::runtime_error & ){
+	last_evaled_argptr(contextptr)=NULL;
       }
 #endif
       unary_function_ptr s(g._SYMBptr->sommet);
@@ -1790,6 +1798,7 @@ namespace giac {
 #ifndef NO_STDEXCEPT
     }
     catch (std::runtime_error & ){
+      last_evaled_argptr(contextptr)=NULL;
       return 0;
     }
 #endif
