@@ -313,12 +313,13 @@ namespace giac {
 	return dexponent*ln(base,contextptr)*s+exponent*dbase*s/v[1];
       }
       if (vs>=3 && s.sommet==at_Beta){
-	gen v0=v[0],v1=v[1],v2=v[2],v3=v[3]; 
+	gen v0=v[0],v1=v[1],v2=v[2]; 
 	if (!is_zero(derive(v0,i,contextptr)) || !is_zero(derive(v1,i,contextptr)) )
 	  return gensizeerr("diff of incomplete beta with respect to non constant 1st or 2nd arg not implemented");
 	// diff/v2 of int_0^v2 t^(v0-1)*(1-t)^(v1-1) dt
 	gen tmp=pow(v2,v0-1,contextptr)*pow(1-v2,v1-1,contextptr)*derive(v2,i,contextptr);
 	if (vs==4){
+	  gen v3=v[3];
 	  if (is_one(v3))
 	    return tmp/Beta(v0,v1,contextptr);
 	  return gensizeerr(contextptr);
@@ -331,15 +332,15 @@ namespace giac {
       if (vs==4 && s.sommet==at_sum){
 	gen v0=v[0],v1=v[1],v2=v[2],v3=v[3];
 	if (!is_zero(derive(v1,i,contextptr)) || !is_zero(derive(v2,i,contextptr)) || ! is_zero(derive(v3,i,contextptr)) )
-	  return gensizeerr("diff of sum with boundaries or mute variable depending on differentiation variable");
+	  return gensizeerr(gettext("diff of sum with boundaries or mute variable depending on differentiation variable"));
 	if (is_inf(v2) || is_inf(v3))
-	  *logptr(contextptr) << "Warning, assuming derivative commutes with infinite sum" << endl;
+	  *logptr(contextptr) << gettext("Warning, assuming derivative commutes with infinite sum") << endl;
 	return _sum(makesequence(derive(v0,i,contextptr),v1,v2,v3),contextptr);
       }
       if ( (vs==2 || (vs==3 && is_zero(v[2]))) && (s.sommet==at_upper_incomplete_gamma || s.sommet==at_lower_incomplete_gamma || s.sommet==at_Gamma)){
 	gen v0=v[0],v1=v[1]; 
 	if (!is_zero(derive(v0,i,contextptr)))
-	  return gensizeerr("diff of incomplete gamma with respect to non constant 1st arg not implemented");
+	  return gensizeerr(gettext("diff of incomplete gamma with respect to non constant 1st arg not implemented"));
 	// diff(int_v1^inf exp(-t)*t^(v0-1) dt)
 	gen tmp1=exp(-v1,contextptr)*pow(v1,v0-1,contextptr)*derive(v1,i,contextptr);
 	return (s.sommet==at_lower_incomplete_gamma)?tmp1:-tmp1;
@@ -712,6 +713,7 @@ namespace giac {
     try {
       res=_derive(args,contextptr);
     } catch (std::runtime_error & e){
+      last_evaled_argptr(contextptr)=NULL;
       res=string2gen(e.what(),false);
       res.subtype=-1;
     }
@@ -722,10 +724,13 @@ namespace giac {
       --step_infolevel(contextptr);
     return res;
   }
+  gen _diff(const gen & g,GIAC_CONTEXT){
+    return _derive(g,contextptr);
+  }
   static const char _derive_s []="diff";
   static string printasderive(const gen & feuille,const char * sommetstr,GIAC_CONTEXT){
     if (feuille.type!=_VECT){
-      if (need_parenthesis(feuille))
+      if (feuille.type>=_POLY && feuille.type!=_IDNT)
 	return "("+feuille.print()+")'";
       return feuille.print()+"'";
     }
@@ -797,7 +802,7 @@ namespace giac {
     vecteur ls=lidnt(s);
     for (int i=0;i<int(ls.size());++i){
       if (ls[i]==var || (var.type==_VECT && equalposcomp(*var._VECTptr,ls[i])))
-	return gensizeerr("solve error while finding critical points");
+	return gensizeerr(gettext("solve error while finding critical points"));
     }
     if (s.type==_VECT){
       vecteur res;
@@ -890,12 +895,15 @@ namespace giac {
     else
       return s;
   }
+
+#if defined USE_GMP_REPLACEMENTS || defined GIAC_GGB
   gen _extrema(const gen & g,GIAC_CONTEXT){
     return critical(g,true,contextptr);
   }
   static const char _extrema_s []="extrema";
   static define_unary_function_eval_quoted (__extrema,&_extrema,_extrema_s);
   define_unary_function_ptr5( at_extrema ,alias_at_extrema,&__extrema,_QUOTE_ARGUMENTS,true);
+#endif
 
   gen _critical(const gen & g,GIAC_CONTEXT){
     return critical(g,false,contextptr);
@@ -947,10 +955,24 @@ namespace giac {
 
   gen _implicit_diff(const gen & args,GIAC_CONTEXT){
     if (is_undef(args)) return args;
-    if (args.type!=_VECT || args._VECTptr->size()!=3)
+    if (args.type!=_VECT || (args._VECTptr->size()!=3 && args._VECTptr->size()!=4))
       return gensizeerr(contextptr);
-    gen eq(remove_equal(args._VECTptr->front())),x((*args._VECTptr)[1]),y(args._VECTptr->back());
-    return -derive(eq,x,contextptr)/derive(eq,y,contextptr);
+    int ndiff=1;
+    if (args._VECTptr->size()==4){
+      gen g=args._VECTptr->back();
+      if (!is_integral(g) || g.type!=_INT_ || g.val<1)
+	return gensizeerr(contextptr);
+      ndiff=g.val;
+    }
+    gen eq(remove_equal(args._VECTptr->front())),x((*args._VECTptr)[1]),y((*args._VECTptr)[2]);
+    gen yprime=-derive(eq,x,contextptr)/derive(eq,y,contextptr);
+    if (ndiff==1)
+      return yprime;
+    gen yn=yprime;
+    for (int n=2;n<=ndiff;++n){
+      yn=ratnormal(derive(yn,x,contextptr)+derive(yn,y,contextptr)*yprime,contextptr);
+    }
+    return yn;
   }
   static const char _implicit_diff_s []="implicit_diff";
   static define_unary_function_eval (__implicit_diff,&_implicit_diff,_implicit_diff_s);
@@ -980,7 +1002,7 @@ namespace giac {
 	  excluded=mergevecteur(excluded,gen2vecteur(_solve(makesequence(symb_equal(gf[0],0),x),contextptr)));
 	  continue;
 	}
-	if (is_greater(gf[1],0,contextptr))
+	if (is_constant_wrt(gf[1],x,contextptr) && is_greater(gf[1],0,contextptr))
 	  eqs.push_back(symb_superieur_egal(gf[0],0));
 	else
 	  eqs.push_back(symb_superieur_strict(gf[0],0));
@@ -1014,7 +1036,7 @@ namespace giac {
 	continue;
       if (u==at_floor || u==at_ceil || u==at_round || u==at_abs || u==at_sign || u==at_max || u==at_min)
 	continue;
-      *logptr(contextptr) << g << " function not supported, doing like if it was defined" << endl;
+      *logptr(contextptr) << g << gettext(" function not supported, doing like if it was defined") << endl;
     }
   }
   gen domain(const gen & f,const gen & x,int mode,GIAC_CONTEXT){
@@ -1032,7 +1054,10 @@ namespace giac {
       domain(f,x,eqs,excluded,mode,contextptr);
       res=gen2vecteur(_solve(makesequence(eqs,x),contextptr));
 #ifndef NO_STDEXCEPT
-    } catch (std::runtime_error & e ) { *logptr(contextptr) << e.what() << endl;}
+    } catch (std::runtime_error & e ) { 
+      last_evaled_argptr(contextptr)=NULL;
+      *logptr(contextptr) << e.what() << endl;
+    }
 #endif
     complex_mode(b,contextptr);
     comprim(excluded);
@@ -1055,7 +1080,7 @@ namespace giac {
 	  if (is_zero(resi))
 	    continue;
 	  if (!res[i].is_symb_of_sommet(at_and)){
-	    res[i]=symbolic(at_and,makesequence(res[i],tmp));
+	    res[i]=symbolic(at_and,makesequence(res[i],tmp[j]));
 	    continue;
 	  }
 	  vecteur v=gen2vecteur(res[i]._SYMBptr->feuille);
