@@ -156,7 +156,7 @@ void dealloc(struct Tgraph *graph);
 static int texmacs_counter= 0;
 
 
-#ifdef VISUALC
+#ifndef HAVE_LIBFLTK
 using namespace giac;
 #define STDIN_FILENO 0
 namespace xcas {
@@ -437,24 +437,24 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
   COUT << "Partly inspired from pgiac by Jean-Michel Sarlat" << endl;
   if (!giac::is_file_available("giac.tex")){
     if (giac::is_file_available("/usr/share/giac/doc/giac.tex"))
-      system("cp /usr/share/giac/doc/giac.tex .");
+      giac::system_no_deprecation("cp /usr/share/giac/doc/giac.tex .");
     else {
       if (giac::is_file_available("/usr/local/share/giac/doc/giac.tex"))
-	system("cp /usr/local/share/giac/doc/giac.tex .");
+	giac::system_no_deprecation("cp /usr/local/share/giac/doc/giac.tex .");
       else 
 	if (giac::is_file_available("/Applications/share/giac/doc/giac.tex"))
-	  system("cp /Applications/share/giac/doc/giac.tex .");
+	  giac::system_no_deprecation("cp /Applications/share/giac/doc/giac.tex .");
     }
   }
   if (!giac::is_file_available("giacfr.tex")){
     if (giac::is_file_available("/usr/share/giac/doc/giacfr.tex"))
-      system("cp /usr/share/giac/doc/giacfr.tex .");
+      giac::system_no_deprecation("cp /usr/share/giac/doc/giacfr.tex .");
     else {
       if (giac::is_file_available("/usr/local/share/giac/doc/giacfr.tex"))
-	system("cp /usr/local/share/giac/doc/giacfr.tex .");
+	giac::system_no_deprecation("cp /usr/local/share/giac/doc/giacfr.tex .");
       else 
 	if (giac::is_file_available("/Applications/share/giac/doc/giacfr.tex"))
-	  system("cp /Applications/share/giac/doc/giacfr.tex .");
+	  giac::system_no_deprecation("cp /Applications/share/giac/doc/giacfr.tex .");
     }
   }
   std::string infile_=giac::remove_extension(infile),warn;
@@ -525,15 +525,15 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	  if (dohevea){
 	    std::string cmd="hevea -fix "+infile_+" &";
 	    COUT << "Running " << cmd << endl;
-	    system(cmd.c_str());
+	    giac::system_no_deprecation(cmd.c_str());
 	  }
 	  else
 	    COUT << "For HTML5 output, you can run\nhevea -fix " << infile_ << endl;
 	  std::string cmd="makeindex "+giac::remove_extension(outfile);
-	  system(cmd.c_str());
+	  giac::system_no_deprecation(cmd.c_str());
 	  cmd=("pdflatex "+giac::remove_extension(outfile)+" && mv "+giac::remove_extension(outfile)+".pdf "+infile_+".pdf");
 	  COUT << cmd << endl;
-	  system(cmd.c_str());
+	  giac::system_no_deprecation(cmd.c_str());
 	  if (!warn.empty()){
 	    COUT << "*********************************" << endl;
 	    COUT << "*********************************" << endl;
@@ -688,7 +688,7 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
   }
   out.close();
   COUT << "Missing \\end{document}. File " << outfile << " created" << endl;
-  //system(("pgiac "+outfile).c_str());
+  //giac::system_no_deprecation(("pgiac "+outfile).c_str());
 }
 
 #else
@@ -751,10 +751,10 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	  out.close();
 	  COUT << "File " << outfile << " created, now running hevea in background and pgiac " << outfile << endl << "Then I will run pdflatex " << giac::remove_extension(outfile) << endl << "For HTML5 output, you can run\nhevea -fix " << giac::remove_extension(infile) << endl;
 	  std::string cmd="hevea -fix "+giac::remove_extension(infile)+" &";
-	  system(cmd.c_str());
+	  giac::system_no_deprecation(cmd.c_str());
 	  cmd=("pgiac "+outfile+" && pdflatex "+giac::remove_extension(outfile)+" && mv "+giac::remove_extension(outfile)+".pdf "+giac::remove_extension(infile)+".pdf");
 	  COUT << cmd << endl;
-	  system(cmd.c_str());
+	  giac::system_no_deprecation(cmd.c_str());
 	  return;
 	}
       }
@@ -874,7 +874,7 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
   }
   out.close();
   COUT << "Missing \\end{document}. File " << outfile << " created, now running pgiac" << endl;
-  system(("pgiac "+outfile).c_str());
+  giac::system_no_deprecation(("pgiac "+outfile).c_str());
 }
 #endif
 
@@ -948,7 +948,8 @@ int main(int ARGC, char *ARGV[]){
   }
 #endif
   if (ARGC==2 && (string(ARGV[1])=="-v" || string(ARGV[1])=="--version" ) ){
-    cout << VERSION << endl;
+    cout << "// (c) 2001, 2018 B. Parisse & others" << endl;
+    cout << GIAC_VERSION << endl;
 #ifndef GNUWINCE
     return 0;
 #endif
@@ -1101,7 +1102,7 @@ int main(int ARGC, char *ARGV[]){
     printf("Giac CAS for mupacs, released under the GPL license 3.0\n");
     printf("See http://www.gnu.org for license details\n");
     printf("May contain BSD licensed software parts (lapack, atlas, tinymt)\n");
-    printf("| (c) 2006, 2016 B. Parisse & al (giac), F.Maltey & al (mupacs) |\n");
+    printf("| (c) 2006, 2018 B. Parisse & al (giac), F.Maltey & al (mupacs) |\n");
     putchar(EMACS_DATA_END);
     bool prompt=true;
     for (int k=0;;++k) {
@@ -1293,7 +1294,7 @@ int main(int ARGC, char *ARGV[]){
     printf("|     Giac CAS for TeXmacs, released under the GPL license (3.0)    |\n");
     printf("|     See http://www.gnu.org for license details                    |\n");
     printf("|  May contain BSD licensed software parts (lapack, atlas, tinymt)  |\n");
-    printf("| (c) 2003,2016 B. Parisse & al (giac), J. van der Hoeven (TeXmacs) |\n");
+    printf("| (c) 2003,2018 B. Parisse & al (giac), J. van der Hoeven (TeXmacs) |\n");
     printf("--------------------------------------------------------------------\n");
     switch (giac::xcas_mode(contextptr)){
     case 0:
@@ -1504,7 +1505,7 @@ int main(int ARGC, char *ARGV[]){
     struct tms start, end;  
     using_history();
     cout << "Welcome to giac readline interface" << endl;
-    cout << "(c) 2001,2016 B. Parisse & others" << endl;
+    cout << "(c) 2001,2018 B. Parisse & others" << endl;
     cout << "Homepage http://www-fourier.ujf-grenoble.fr/~parisse/giac.html" << endl;
     cout << "Released under the GPL license 3.0 or above" << endl;
     cout << "See http://www.gnu.org for license details" << endl;
@@ -1552,6 +1553,8 @@ int main(int ARGC, char *ARGV[]){
       giac::messages_to_print="";
 #endif
       giac::gen gq(s,contextptr),ge;
+      if (giac::python_compat(contextptr))
+	gq=giac::equaltosto(gq,contextptr);
       if (giac::first_error_line(contextptr)){
 	cout << parser_error(contextptr);
       }
