@@ -238,6 +238,12 @@ namespace giac {
     gen xval=x._IDNTptr->eval(1,x,contextptr);
     if (xval!=x){
       _purge(x,contextptr);
+      xval=x._IDNTptr->eval(1,x,contextptr);
+      if (xval!=x){
+	string s="Unable to purge "+x.print(contextptr)+ ", choose another free variable name";
+	*logptr(contextptr) << s << endl;
+	return gensizeerr(s);
+      }
       gen res=residue(g_,x,a,contextptr);
       sto(xval,x,contextptr);
       return res;
@@ -573,6 +579,23 @@ namespace giac {
     // check if g may be integrated using the residue formula
     gen A,B,P;
     int typeint=rational?2:is_meromorphic(g,x,A,B,P,contextptr);
+    if (typeint==6 && a==minus_inf && b==plus_inf && is_zero(P) && is_constant_wrt(A,x,contextptr) && lvarxwithinv(B,x,contextptr).size()<2 && is_strictly_positive(-A[0],contextptr)){
+      gen A_(A[0]),B_(A[1]),C_(A[2]);
+      gen der(2*A_*x+B_),tmp(B);
+      B=0;
+      while (!is_zero(tmp,contextptr)){
+	tmp=_quorem(makesequence(tmp,der,x),contextptr);
+	if (tmp.type!=_VECT || tmp._VECTptr->size()!=2)
+	  return false;
+	B += tmp._VECTptr->back();
+	tmp=-derive(tmp._VECTptr->front(),x,contextptr);
+      }
+      // int(exp(A_*x^2+B_*x+C_)*B,x,-inf,inf)
+      // =int(exp(A_*(x+B_/2/A_)^2+(-B_^2/4/A_+C_))*B,x,-inf,inf)
+      // =sqrt(pi/A_)*B*exp(B_^2/4/A_-C_)
+      res=sqrt(-cst_pi/A_,contextptr)*B*exp(ratnormal(C_-B_*B_/4/A_,contextptr),contextptr);
+      return true;
+    }
     if (typeint==5){ 
       // A*ln(P(x))+B, A/B/P rational fractions
       bool estreel=is_zero(im(A,contextptr))&&is_zero(im(P,contextptr));
@@ -831,6 +854,7 @@ namespace giac {
 	}
 #ifndef NO_STDEXCEPT
       } catch (...){
+	last_evaled_argptr(contextptr)=NULL;
 	return false;
       }
 #endif
@@ -1068,7 +1092,7 @@ namespace giac {
 	  res=0;
 	  return true;
 	}
-	if (intgab_r(g,x,a,b,rational,res,contextptr))
+	if (is_zero(A) && intgab_r(g,x,a,b,rational,res,contextptr))
 	  return true;
 	if (ieo==1){
 	  // simplify g on 0..inf
@@ -1131,7 +1155,7 @@ namespace giac {
 		  res=0;
 		  vecteur v=*ganv._VECTptr;
 		  gen facti=pow(expo_a,-2,contextptr);
-		  for (int i=1;i<v.size();++i){
+		  for (int i=1;i<int(v.size());++i){
 		    gen coeff=v[v.size()-i-1];
 		    if (!is_zero(coeff))
 		      res += coeff*facti*Zeta(i+1,contextptr);
@@ -1227,6 +1251,8 @@ namespace giac {
     if (!has_evalf(gm,gabd,1,contextptr) || is_zero(gabd))
       gm=simplify(gm,contextptr);
     if (is_constant_wrt(g,x,contextptr)){
+      if (contains(g,x))
+	g=ratnormal(g,contextptr);
       res=g*(b-a);
       return true;
     }
@@ -1374,6 +1400,7 @@ namespace giac {
       }
 #ifndef NO_STDEXCEPT
     } catch (std::runtime_error & ){
+      last_evaled_argptr(contextptr)=NULL;
     }
 #endif
     return false;
