@@ -1,6 +1,7 @@
 {"%",13,-124,0,*((ulonglong *) at_PERCENT)},
 {"%CHANGE",13,-124,0,*((ulonglong *) at_PERCENTCHANGE)},
 {"%TOTAL",13,-124,0,*((ulonglong *) at_PERCENTTOTAL)},
+{".",13,9,0,*((ulonglong *) at_struct_dot)| 1},
 {"ABS",13,-124,0,*((ulonglong *) at_ABS)},
 {"ACOS",13,-124,0,*((ulonglong *) at_ACOS)},
 {"ACOSH",13,-124,0,*((ulonglong *) at_ACOSH)},
@@ -40,7 +41,7 @@
 {"COT",13,-124,0,*((ulonglong *) at_COT)},
 {"CROSS",13,-124,0,*((ulonglong *) at_CROSS)},
 {"CSC",13,-124,0,*((ulonglong *) at_CSC)},
-{"Celsius2Fahrenheit",13,-124,0,*((ulonglong *) at_Celsius2Fahrenheit)},
+{"Celsius2Fahrenheit",13,9,0,*((ulonglong *) at_Celsius2Fahrenheit)},
 {"Ci",13,9,0,*((ulonglong *) at_Ci)},
 {"Ci0",13,9,0,*((ulonglong *) at_Ci0)},
 {"Circle",13,77,0,*((ulonglong *) at_Circle)},
@@ -84,7 +85,7 @@
 {"FNROOT",13,-124,0,*((ulonglong *) at_FNROOT)| 1},
 {"FP",13,-124,0,*((ulonglong *) at_FP)},
 {"Factor",13,9,0,*((ulonglong *) at_Factor)},
-{"Fahrenheit2Celsius",13,-124,0,*((ulonglong *) at_Fahrenheit2Celsius)},
+{"Fahrenheit2Celsius",13,9,0,*((ulonglong *) at_Fahrenheit2Celsius)},
 {"Fill",13,77,0,*((ulonglong *) at_Fill)| 1},
 {"GETKEY",13,-124,0,*((ulonglong *) at_GETKEY)},
 {"GF",13,9,0,*((ulonglong *) at_GF)},
@@ -101,6 +102,7 @@
 {"IFTE",13,85,0,*((ulonglong *) at_IFTE)},
 {"IM",13,-124,0,*((ulonglong *) at_IM)},
 {"INPUT",13,-124,0,*((ulonglong *) at_INPUT)| 1},
+{"INTERSECT",13,-124,0,*((ulonglong *) at_INTERSECT)},
 {"INVERSE",13,-124,0,*((ulonglong *) at_INVERSE)},
 {"IP",13,-124,0,*((ulonglong *) at_IP)},
 {"ISOLATE",13,-124,0,*((ulonglong *) at_ISOLATE)| 1},
@@ -110,8 +112,9 @@
 {"Int",13,9,0,*((ulonglong *) at_Int)},
 {"Inverse",13,9,0,*((ulonglong *) at_Inverse)},
 {"JordanBlock",13,9,0,*((ulonglong *) at_JordanBlock)},
+{"Kronecker",13,9,0,*((ulonglong *) at_Kronecker)},
 {"LINE",13,-124,0,*((ulonglong *) at_LINE)},
-{"LINEAR?",13,-124,0,*((ulonglong *) at_LINEAR?)| 1},
+{"LINEAR?",13,-124,0,*((ulonglong *) at_IS_LINEAR)| 1},
 {"LN",13,-124,0,*((ulonglong *) at_LN)},
 {"LNP1",13,-124,0,*((ulonglong *) at_LNP1)},
 {"LOG",13,-124,0,*((ulonglong *) at_LOG)},
@@ -130,6 +133,7 @@
 {"MAXREAL",13,2,0,*((ulonglong *) at_MAXREAL)},
 {"MIN",13,-124,0,*((ulonglong *) at_MIN)},
 {"MINREAL",13,2,0,*((ulonglong *) at_MINREAL)},
+{"MINUS",13,-124,0,*((ulonglong *) at_MINUS)},
 {"MOD",13,21,0,*((ulonglong *) at_MOD)},
 {"MSGBOX",13,-124,0,*((ulonglong *) at_MSGBOX)},
 {"NOP",13,85,0,*((ulonglong *) at_NOP)},
@@ -137,6 +141,7 @@
 {"NTHROOT",13,23,0,*((ulonglong *) at_NTHROOT)},
 {"NewFold",13,77,0,*((ulonglong *) at_NewFold)| 1},
 {"NewPic",13,77,0,*((ulonglong *) at_NewPic)},
+{"Nop",13,9,0,*((ulonglong *) at_Nop)},
 {"Nullspace",13,9,0,*((ulonglong *) at_Nullspace)},
 {"OVER",13,85,0,*((ulonglong *) at_OVER)},
 {"Output",13,77,0,*((ulonglong *) at_Output)},
@@ -232,6 +237,7 @@
 {"TRN",13,-124,0,*((ulonglong *) at_TRN)},
 {"TRUNCATE",13,-124,0,*((ulonglong *) at_TRUNCATE)},
 {"TeX",13,9,0,*((ulonglong *) at_TeX)},
+{"UNION",13,-124,0,*((ulonglong *) at_UNION)},
 {"UTPC",13,9,0,*((ulonglong *) at_UTPC)},
 {"UTPF",13,9,0,*((ulonglong *) at_UTPF)},
 {"UTPN",13,9,0,*((ulonglong *) at_UTPN)},
@@ -257,8 +263,10 @@
 {"acos2atan",13,9,0,*((ulonglong *) at_acos2atan)},
 {"acosh",13,9,0,*((ulonglong *) at_acosh)},
 {"acot",13,9,0,*((ulonglong *) at_acot)},
+{"acoth",13,9,0,*((ulonglong *) at_acoth)},
 {"acsc",13,9,0,*((ulonglong *) at_acsc)},
 {"add",13,9,0,*((ulonglong *) at_add)| 1},
+{"add_autosimplify",13,9,0,*((ulonglong *) at_add_autosimplify)| 1},
 {"add_language",13,9,0,*((ulonglong *) at_add_language)},
 {"additionally",13,9,0,*((ulonglong *) at_additionally)| 1},
 {"adjoint_matrix",13,9,0,*((ulonglong *) at_adjoint_matrix)},
@@ -298,22 +306,27 @@
 {"asin2acos",13,9,0,*((ulonglong *) at_asin2acos)},
 {"asin2atan",13,9,0,*((ulonglong *) at_asin2atan)},
 {"asinh",13,9,0,*((ulonglong *) at_asinh)},
+{"assert",13,77,0,*((ulonglong *) at_assert)| 1},
 {"assign",13,9,0,*((ulonglong *) at_assign)},
 {"assume",13,9,0,*((ulonglong *) at_assume)| 1},
 {"atan",13,9,0,*((ulonglong *) at_atan)},
+{"atan2",13,9,0,*((ulonglong *) at_atan2)},
 {"atan2acos",13,9,0,*((ulonglong *) at_atan2acos)},
 {"atan2asin",13,9,0,*((ulonglong *) at_atan2asin)},
 {"atanh",13,9,0,*((ulonglong *) at_atanh)},
 {"atrig2ln",13,9,0,*((ulonglong *) at_atrig2ln)},
 {"augment",13,9,0,*((ulonglong *) at_augment)},
+{"auto_correlation",13,9,0,*((ulonglong *) at_auto_correlation)},
 {"autosimplify",13,9,0,*((ulonglong *) at_autosimplify)},
 {"avance",13,126,0,*((ulonglong *) at_avance)},
 {"avgRC",13,9,0,*((ulonglong *) at_avgRC)},
 {"back",13,9,0,*((ulonglong *) at_back)},
 {"background",13,9,0,*((ulonglong *) at_background)| 1},
+{"backward",13,9,0,*((ulonglong *) at_backward)},
 {"baisse_crayon",13,126,0,*((ulonglong *) at_baisse_crayon)},
 {"bar_plot",13,9,0,*((ulonglong *) at_bar_plot)},
 {"barplot",13,9,0,*((ulonglong *) at_barplot)},
+{"bartlett_hann_window",13,9,0,*((ulonglong *) at_bartlett_hann_window)},
 {"barycenter",13,9,0,*((ulonglong *) at_barycenter)},
 {"basis",13,9,0,*((ulonglong *) at_basis)},
 {"batons",13,9,0,*((ulonglong *) at_batons)},
@@ -337,8 +350,12 @@
 {"bitor",13,9,0,*((ulonglong *) at_bitor)},
 {"bitxor",13,9,0,*((ulonglong *) at_bitxor)},
 {"black",13,2,0,*((ulonglong *) at_black)},
+{"blackman_harris_window",13,9,0,*((ulonglong *) at_blackman_harris_window)},
+{"blackman_window",13,9,0,*((ulonglong *) at_blackman_window)},
 {"blockmatrix",13,9,0,*((ulonglong *) at_blockmatrix)},
+{"blockmatrix_mult_size",13,9,0,*((ulonglong *) at_blockmatrix_mult_size)},
 {"blue",13,2,0,*((ulonglong *) at_blue)},
+{"bohman_window",13,9,0,*((ulonglong *) at_bohman_window)},
 {"border",13,9,0,*((ulonglong *) at_border)},
 {"bounded_function",13,9,0,*((ulonglong *) at_bounded_function)},
 {"boxwhisker",13,9,0,*((ulonglong *) at_boxwhisker)},
@@ -386,12 +403,16 @@
 {"chisquared_cdf",13,9,0,*((ulonglong *) at_chisquared_cdf)},
 {"chisquared_icdf",13,9,0,*((ulonglong *) at_chisquared_icdf)},
 {"chisquaret",13,9,0,*((ulonglong *) at_chisquaret)},
+{"choice",13,9,0,*((ulonglong *) at_choice)},
 {"cholesky",13,9,0,*((ulonglong *) at_cholesky)},
 {"choosebox",13,9,0,*((ulonglong *) at_choosebox)| 1},
+{"chr",13,9,0,*((ulonglong *) at_chr)},
 {"chrem",13,9,0,*((ulonglong *) at_chrem)},
 {"circle",13,9,0,*((ulonglong *) at_circle)| 1},
 {"circumcircle",13,9,0,*((ulonglong *) at_circumcircle)},
 {"classes",13,9,0,*((ulonglong *) at_classes)},
+{"clear",13,9,0,*((ulonglong *) at_clear)| 1},
+{"clearscreen",13,126,0,*((ulonglong *) at_clearscreen)},
 {"click",13,9,0,*((ulonglong *) at_click)| 1},
 {"close",13,9,0,*((ulonglong *) at_close)| 1},
 {"coeff",13,9,0,*((ulonglong *) at_coeff)},
@@ -413,6 +434,7 @@
 {"common_perpendicular",13,9,0,*((ulonglong *) at_common_perpendicular)},
 {"companion",13,9,0,*((ulonglong *) at_companion)},
 {"compare",13,9,0,*((ulonglong *) at_compare)},
+{"complex",13,9,0,*((ulonglong *) at_complex)},
 {"complexroot",13,9,0,*((ulonglong *) at_complexroot)},
 {"concat",13,9,0,*((ulonglong *) at_concat)},
 {"cond",13,9,0,*((ulonglong *) at_cond)},
@@ -428,14 +450,17 @@
 {"convert3d",13,9,0,*((ulonglong *) at_convert3d)},
 {"convertir",13,9,0,*((ulonglong *) at_convertir)},
 {"convexhull",13,9,0,*((ulonglong *) at_convexhull)},
+{"convolution",13,9,0,*((ulonglong *) at_convolution)},
 {"coordinates",13,9,0,*((ulonglong *) at_coordinates)},
 {"copy",13,9,0,*((ulonglong *) at_copy)},
 {"correlation",13,9,0,*((ulonglong *) at_correlation)},
 {"cos",13,9,0,*((ulonglong *) at_cos)},
 {"cos2sintan",13,9,0,*((ulonglong *) at_cos2sintan)},
 {"cosh",13,9,0,*((ulonglong *) at_cosh)},
+{"cosine_window",13,9,0,*((ulonglong *) at_cosine_window)},
 {"cot",13,9,0,*((ulonglong *) at_cot)},
 {"cote",13,9,0,*((ulonglong *) at_cote)},
+{"coth",13,9,0,*((ulonglong *) at_coth)},
 {"count",13,9,0,*((ulonglong *) at_count)},
 {"count_eq",13,9,0,*((ulonglong *) at_count_eq)},
 {"count_inf",13,9,0,*((ulonglong *) at_count_inf)},
@@ -445,14 +470,18 @@
 {"covariance",13,9,0,*((ulonglong *) at_covariance)},
 {"covariance_correlation",13,9,0,*((ulonglong *) at_covariance_correlation)},
 {"cpartfrac",13,9,0,*((ulonglong *) at_cpartfrac)},
+{"cpp",13,9,0,*((ulonglong *) at_cpp)| 1},
+{"cprint",13,9,0,*((ulonglong *) at_cprint)| 1},
 {"crationalroot",13,9,0,*((ulonglong *) at_crationalroot)},
 {"crayon",13,126,0,*((ulonglong *) at_crayon)},
 {"critical",13,9,0,*((ulonglong *) at_critical)| 1},
 {"cross",13,9,0,*((ulonglong *) at_cross)},
 {"crossP",13,9,0,*((ulonglong *) at_crossP)},
+{"cross_correlation",13,9,0,*((ulonglong *) at_cross_correlation)},
 {"cross_ratio",13,9,0,*((ulonglong *) at_cross_ratio)},
 {"crossproduct",13,9,0,*((ulonglong *) at_crossproduct)},
 {"csc",13,9,0,*((ulonglong *) at_csc)},
+{"csch",13,9,0,*((ulonglong *) at_csch)},
 {"csolve",13,9,0,*((ulonglong *) at_csolve)| 1},
 {"csv2gen",13,9,0,*((ulonglong *) at_csv2gen)},
 {"cube",13,9,0,*((ulonglong *) at_cube)},
@@ -474,10 +503,11 @@
 {"de",13,57,0,*((ulonglong *) at_de)| 1},
 {"deSolve",13,77,0,*((ulonglong *) at_deSolve)| 1},
 {"debug",13,9,0,*((ulonglong *) at_debug)| 1},
-{"debug_infolevel",13,9,0,*((ulonglong *) at_debug_infolevel)},
+{"debug_infolevel",13,5,0,*((ulonglong *) at_debug_infolevel)},
 {"debut_enregistrement",13,126,0,*((ulonglong *) at_debut_enregistrement)},
 {"decrement",13,9,0,*((ulonglong *) at_decrement)| 1},
 {"degree",13,9,0,*((ulonglong *) at_degree)},
+{"del",13,77,0,*((ulonglong *) at_del)| 1},
 {"delcols",13,9,0,*((ulonglong *) at_delcols)},
 {"delrows",13,9,0,*((ulonglong *) at_delrows)},
 {"deltalist",13,9,0,*((ulonglong *) at_deltalist)},
@@ -509,15 +539,19 @@
 {"divis",13,9,0,*((ulonglong *) at_divis)},
 {"division_point",13,9,0,*((ulonglong *) at_division_point)},
 {"divisors",13,9,0,*((ulonglong *) at_divisors)},
+{"divmod",13,9,0,*((ulonglong *) at_divmod)},
 {"divpc",13,9,0,*((ulonglong *) at_divpc)},
 {"dodecahedron",13,9,0,*((ulonglong *) at_dodecahedron)},
+{"domain",13,9,0,*((ulonglong *) at_domain)},
 {"dot",13,9,0,*((ulonglong *) at_dot)},
 {"dotP",13,9,0,*((ulonglong *) at_dotP)},
 {"dot_paper",13,9,0,*((ulonglong *) at_dot_paper)},
 {"dotprod",13,9,0,*((ulonglong *) at_dotprod)},
+{"draw_string",13,9,0,*((ulonglong *) at_draw_string)},
 {"droit",13,9,0,*((ulonglong *) at_droit)},
 {"droite_tangente",13,9,0,*((ulonglong *) at_droite_tangente)},
 {"dsolve",13,9,0,*((ulonglong *) at_dsolve)| 1},
+{"dtype",13,9,0,*((ulonglong *) at_dtype)},
 {"e2r",13,9,0,*((ulonglong *) at_e2r)},
 {"ecart_type",13,9,0,*((ulonglong *) at_ecart_type)},
 {"ecart_type_population",13,9,0,*((ulonglong *) at_ecart_type_population)},
@@ -578,8 +612,9 @@
 {"exponentiald_cdf",13,9,0,*((ulonglong *) at_exponentiald_cdf)},
 {"exponentiald_icdf",13,9,0,*((ulonglong *) at_exponentiald_icdf)},
 {"expr",13,9,0,*((ulonglong *) at_expr)},
+{"extend",13,9,0,*((ulonglong *) at_extend)},
 {"extract_measure",13,9,0,*((ulonglong *) at_extract_measure)},
-{"extrema",13,9,0,*((ulonglong *) at_extrema)| 1},
+{"extrema",13,9,0,*((ulonglong *) at_extrema)},
 {"ezgcd",13,9,0,*((ulonglong *) at_ezgcd)},
 {"f2nd",13,9,0,*((ulonglong *) at_f2nd)},
 {"fMax",13,9,0,*((ulonglong *) at_fMax)},
@@ -599,8 +634,10 @@
 {"fclose",13,9,0,*((ulonglong *) at_fclose)| 1},
 {"fcoeff",13,9,0,*((ulonglong *) at_fcoeff)},
 {"fft",13,9,0,*((ulonglong *) at_fft)},
+{"fft_mult_size",13,9,0,*((ulonglong *) at_fft_mult_size)},
 {"fieldplot",13,9,0,*((ulonglong *) at_fieldplot)},
 {"filled",13,2,0,*((ulonglong *) at_filled)},
+{"filter",13,9,0,*((ulonglong *) at_filter)},
 {"fin_enregistrement",13,126,0,*((ulonglong *) at_fin_enregistrement)},
 {"find",13,9,0,*((ulonglong *) at_find)},
 {"findhelp",13,9,0,*((ulonglong *) at_findhelp)| 1},
@@ -619,6 +656,7 @@
 {"fonction_derivee",13,9,0,*((ulonglong *) at_fonction_derivee)},
 {"fopen",13,9,0,*((ulonglong *) at_fopen)},
 {"format",13,9,0,*((ulonglong *) at_format)},
+{"forward",13,9,0,*((ulonglong *) at_forward)},
 {"fourier_an",13,9,0,*((ulonglong *) at_fourier_an)},
 {"fourier_bn",13,9,0,*((ulonglong *) at_fourier_bn)},
 {"fourier_cn",13,9,0,*((ulonglong *) at_fourier_cn)},
@@ -629,6 +667,7 @@
 {"frame_3d",13,9,0,*((ulonglong *) at_frame_3d)},
 {"frenet",13,9,0,*((ulonglong *) at_frenet)},
 {"frequencies",13,9,0,*((ulonglong *) at_frequencies)},
+{"frexp",13,9,0,*((ulonglong *) at_frexp)},
 {"frobenius_norm",13,9,0,*((ulonglong *) at_frobenius_norm)},
 {"froot",13,9,0,*((ulonglong *) at_froot)},
 {"fsolve",13,9,0,*((ulonglong *) at_fsolve)| 1},
@@ -642,6 +681,7 @@
 {"gauche",13,9,0,*((ulonglong *) at_gauche)},
 {"gauss",13,9,0,*((ulonglong *) at_gauss)},
 {"gauss_seidel_linsolve",13,9,0,*((ulonglong *) at_gauss_seidel_linsolve)},
+{"gaussian_window",13,9,0,*((ulonglong *) at_gaussian_window)},
 {"gaussjord",13,9,0,*((ulonglong *) at_gaussjord)},
 {"gaussquad",13,9,0,*((ulonglong *) at_gaussquad)},
 {"gbasis",13,9,0,*((ulonglong *) at_gbasis)},
@@ -657,7 +697,10 @@
 {"getKey",13,9,0,*((ulonglong *) at_getKey)},
 {"getNum",13,9,0,*((ulonglong *) at_getNum)},
 {"getType",13,9,0,*((ulonglong *) at_getType)},
+{"get_pixel",13,9,0,*((ulonglong *) at_get_pixel)},
 {"ggb_ang",13,9,0,*((ulonglong *) at_ggb_ang)},
+{"ggbalt",13,9,0,*((ulonglong *) at_ggbalt)},
+{"ggbsort",13,9,0,*((ulonglong *) at_ggbsort)},
 {"giac",13,9,0,*((ulonglong *) at_giac)},
 {"goto",13,77,0,*((ulonglong *) at_goto)},
 {"grad",13,9,0,*((ulonglong *) at_grad)| 1},
@@ -679,13 +722,21 @@
 {"halftan_hyp2exp",13,9,0,*((ulonglong *) at_halftan_hyp2exp)},
 {"halt",13,9,0,*((ulonglong *) at_halt)| 1},
 {"hamdist",13,9,0,*((ulonglong *) at_hamdist)},
+{"hamming_window",13,9,0,*((ulonglong *) at_hamming_window)},
+{"hann_poisson_window",13,9,0,*((ulonglong *) at_hann_poisson_window)},
+{"hann_window",13,9,0,*((ulonglong *) at_hann_window)},
 {"harmonic",13,9,0,*((ulonglong *) at_harmonic)},
 {"harmonic_conjugate",13,9,0,*((ulonglong *) at_harmonic_conjugate)},
 {"harmonic_division",13,9,0,*((ulonglong *) at_harmonic_division)| 1},
 {"has",13,9,0,*((ulonglong *) at_has)},
 {"hasard",13,77,0,*((ulonglong *) at_hasard)},
 {"head",13,9,0,*((ulonglong *) at_head)},
+{"heading",13,9,0,*((ulonglong *) at_heading)},
 {"heap_mult",13,9,0,*((ulonglong *) at_heap_mult)},
+{"heapify",13,9,0,*((ulonglong *) at_heapify)},
+{"heappop",13,9,0,*((ulonglong *) at_heappop)},
+{"heappush",13,9,0,*((ulonglong *) at_heappush)},
+{"help",13,9,0,*((ulonglong *) at_help)| 1},
 {"hermite",13,9,0,*((ulonglong *) at_hermite)},
 {"hessenberg",13,9,0,*((ulonglong *) at_hessenberg)},
 {"hessian",13,9,0,*((ulonglong *) at_hessian)| 1},
@@ -693,6 +744,8 @@
 {"hexagon",13,9,0,*((ulonglong *) at_hexagon)| 1},
 {"hexprint",13,9,0,*((ulonglong *) at_hexprint)},
 {"hidden_name",13,2,0,*((ulonglong *) at_hidden_name)},
+{"hideturtle",13,9,0,*((ulonglong *) at_hideturtle)},
+{"highpass",13,9,0,*((ulonglong *) at_highpass)},
 {"hilbert",13,9,0,*((ulonglong *) at_hilbert)},
 {"histogram",13,9,0,*((ulonglong *) at_histogram)},
 {"hold",13,9,0,*((ulonglong *) at_hold)| 1},
@@ -732,6 +785,7 @@
 {"imag",13,9,0,*((ulonglong *) at_imag)},
 {"image",13,9,0,*((ulonglong *) at_image)},
 {"implicit_diff",13,9,0,*((ulonglong *) at_implicit_diff)},
+{"implicitdiff",13,9,0,*((ulonglong *) at_implicitdiff)},
 {"implicitplot",13,9,0,*((ulonglong *) at_implicitplot)},
 {"implicitplot3d",13,9,0,*((ulonglong *) at_implicitplot3d)},
 {"inString",13,9,0,*((ulonglong *) at_inString)},
@@ -739,10 +793,13 @@
 {"incircle",13,9,0,*((ulonglong *) at_incircle)},
 {"increment",13,9,0,*((ulonglong *) at_increment)| 1},
 {"indets",13,9,0,*((ulonglong *) at_indets)},
+{"index",13,9,0,*((ulonglong *) at_index)},
 {"inequationplot",13,9,0,*((ulonglong *) at_inequationplot)| 1},
 {"inferieur_strict_sort",13,9,0,*((ulonglong *) at_inferieur_strict_sort)},
+{"innertln",13,9,0,*((ulonglong *) at_innertln)},
 {"input",13,9,0,*((ulonglong *) at_input)| 1},
 {"inputform",13,9,0,*((ulonglong *) at_inputform)| 1},
+{"insert",13,9,0,*((ulonglong *) at_insert)},
 {"insmod",13,9,0,*((ulonglong *) at_insmod)},
 {"int",13,9,0,*((ulonglong *) at_int)| 1},
 {"intDiv",13,9,0,*((ulonglong *) at_intDiv)},
@@ -763,9 +820,12 @@
 {"invztrans",13,9,0,*((ulonglong *) at_invztrans)},
 {"iquo",13,9,0,*((ulonglong *) at_iquo)},
 {"iquorem",13,9,0,*((ulonglong *) at_iquorem)},
+{"iquosto",13,9,0,*((ulonglong *) at_iquosto)| 1},
 {"iratrecon",13,9,0,*((ulonglong *) at_iratrecon)},
 {"irem",13,9,0,*((ulonglong *) at_irem)},
+{"iremsto",13,9,0,*((ulonglong *) at_iremsto)| 1},
 {"isPrime",13,9,0,*((ulonglong *) at_isPrime)},
+{"is_3dpoint",13,9,0,*((ulonglong *) at_is_3dpoint)},
 {"is_collinear",13,9,0,*((ulonglong *) at_is_collinear)},
 {"is_concyclic",13,9,0,*((ulonglong *) at_is_concyclic)},
 {"is_conjugate",13,9,0,*((ulonglong *) at_is_conjugate)},
@@ -791,7 +851,10 @@
 {"is_rectangle",13,9,0,*((ulonglong *) at_is_rectangle)},
 {"is_rhombus",13,9,0,*((ulonglong *) at_is_rhombus)},
 {"is_square",13,9,0,*((ulonglong *) at_is_square)},
+{"isfinite",13,9,0,*((ulonglong *) at_isfinite)},
+{"isinf",13,9,0,*((ulonglong *) at_isinf)},
 {"ismith",13,9,0,*((ulonglong *) at_ismith)},
+{"isnan",13,9,0,*((ulonglong *) at_isnan)},
 {"isobarycenter",13,9,0,*((ulonglong *) at_isobarycenter)},
 {"isom",13,9,0,*((ulonglong *) at_isom)},
 {"isopolygon",13,9,0,*((ulonglong *) at_isopolygon)},
@@ -800,7 +863,10 @@
 {"ithprime",13,9,0,*((ulonglong *) at_ithprime)},
 {"jacobi_linsolve",13,9,0,*((ulonglong *) at_jacobi_linsolve)},
 {"jacobi_symbol",13,9,0,*((ulonglong *) at_jacobi_symbol)},
+{"javascript",13,9,0,*((ulonglong *) at_javascript)| 1},
+{"join",13,9,0,*((ulonglong *) at_join)},
 {"jordan",13,9,0,*((ulonglong *) at_jordan)},
+{"jump",13,126,0,*((ulonglong *) at_jump)},
 {"jusque",13,58,0,*((ulonglong *) at_jusque)| 1},
 {"ker",13,9,0,*((ulonglong *) at_ker)},
 {"kernel",13,9,0,*((ulonglong *) at_kernel)},
@@ -820,10 +886,12 @@
 {"lcm",13,9,0,*((ulonglong *) at_lcm)},
 {"lcoeff",13,9,0,*((ulonglong *) at_lcoeff)},
 {"ldegree",13,9,0,*((ulonglong *) at_ldegree)},
+{"ldexp",13,9,0,*((ulonglong *) at_ldexp)},
 {"left",13,9,0,*((ulonglong *) at_left)},
 {"legend",13,9,0,*((ulonglong *) at_legend)| 1},
 {"legendre",13,9,0,*((ulonglong *) at_legendre)},
 {"legendre_symbol",13,9,0,*((ulonglong *) at_legendre_symbol)},
+{"len",13,9,0,*((ulonglong *) at_len)},
 {"length",13,9,0,*((ulonglong *) at_length)},
 {"leve_crayon",13,126,0,*((ulonglong *) at_leve_crayon)},
 {"lgcd",13,9,0,*((ulonglong *) at_lgcd)},
@@ -843,13 +911,16 @@
 {"lineariser",13,9,0,*((ulonglong *) at_lineariser)},
 {"lineariser_trigo",13,9,0,*((ulonglong *) at_lineariser_trigo)},
 {"linfnorm",13,9,0,*((ulonglong *) at_linfnorm)},
+{"link2giac",13,9,0,*((ulonglong *) at_link2giac)},
 {"linsolve",13,9,0,*((ulonglong *) at_linsolve)| 1},
 {"linspace",13,9,0,*((ulonglong *) at_linspace)},
 {"lis",13,77,0,*((ulonglong *) at_lis)| 1},
 {"lis_phrase",13,77,0,*((ulonglong *) at_lis_phrase)| 1},
+{"list2exp",13,9,0,*((ulonglong *) at_list2exp)},
 {"list2mat",13,9,0,*((ulonglong *) at_list2mat)},
 {"listplot",13,9,0,*((ulonglong *) at_listplot)},
 {"lll",13,9,0,*((ulonglong *) at_lll)},
+{"lll_reduce",13,9,0,*((ulonglong *) at_lll_reduce)},
 {"ln",13,9,0,*((ulonglong *) at_ln)},
 {"lnGamma_minus",13,9,0,*((ulonglong *) at_lnGamma_minus)},
 {"lname",13,9,0,*((ulonglong *) at_lname)},
@@ -862,6 +933,9 @@
 {"logb",13,9,0,*((ulonglong *) at_logb)},
 {"logistic_regression",13,9,0,*((ulonglong *) at_logistic_regression)},
 {"logistic_regression_plot",13,9,0,*((ulonglong *) at_logistic_regression_plot)},
+{"lower",13,9,0,*((ulonglong *) at_lower)},
+{"lowpass",13,9,0,*((ulonglong *) at_lowpass)},
+{"lpsolve",13,9,0,*((ulonglong *) at_lpsolve)},
 {"lsmod",13,9,0,*((ulonglong *) at_lsmod)},
 {"lsq",13,9,0,*((ulonglong *) at_lsq)},
 {"lu",13,9,0,*((ulonglong *) at_lu)},
@@ -888,6 +962,7 @@
 {"matrix_norm",13,9,0,*((ulonglong *) at_matrix_norm)},
 {"max",13,9,0,*((ulonglong *) at_max)},
 {"max_algext",13,9,0,*((ulonglong *) at_max_algext)},
+{"maximize",13,9,0,*((ulonglong *) at_maximize)},
 {"maxnorm",13,9,0,*((ulonglong *) at_maxnorm)},
 {"mean",13,9,0,*((ulonglong *) at_mean)},
 {"median",13,9,0,*((ulonglong *) at_median)},
@@ -897,6 +972,9 @@
 {"mid",13,9,0,*((ulonglong *) at_mid)},
 {"midpoint",13,9,0,*((ulonglong *) at_midpoint)},
 {"min",13,9,0,*((ulonglong *) at_min)},
+{"min_proba_time",13,9,0,*((ulonglong *) at_min_proba_time)},
+{"minimax",13,9,0,*((ulonglong *) at_minimax)},
+{"minimize",13,9,0,*((ulonglong *) at_minimize)},
 {"mkisom",13,9,0,*((ulonglong *) at_mkisom)},
 {"mksa",13,9,0,*((ulonglong *) at_mksa)},
 {"modgcd",13,9,0,*((ulonglong *) at_modgcd)},
@@ -932,6 +1010,7 @@
 {"newton",13,9,0,*((ulonglong *) at_newton)},
 {"nextperm",13,9,0,*((ulonglong *) at_nextperm)},
 {"nextprime",13,9,0,*((ulonglong *) at_nextprime)},
+{"nlpsolve",13,9,0,*((ulonglong *) at_nlpsolve)},
 {"nodisp",13,9,0,*((ulonglong *) at_nodisp)},
 {"non",13,11,0,*((ulonglong *) at_non)},
 {"non_recursive_normal",13,9,0,*((ulonglong *) at_non_recursive_normal)},
@@ -986,14 +1065,19 @@
 {"pari_unlock",13,9,0,*((ulonglong *) at_pari_unlock)| 1},
 {"part",13,9,0,*((ulonglong *) at_part)},
 {"partfrac",13,9,0,*((ulonglong *) at_partfrac)},
+{"parzen_window",13,9,0,*((ulonglong *) at_parzen_window)},
 {"pas",13,60,0,*((ulonglong *) at_pas)| 1},
 {"pas_de_cote",13,126,0,*((ulonglong *) at_pas_de_cote)},
 {"pcar",13,9,0,*((ulonglong *) at_pcar)},
 {"pcar_hessenberg",13,9,0,*((ulonglong *) at_pcar_hessenberg)},
 {"pcoeff",13,9,0,*((ulonglong *) at_pcoeff)},
+{"pencolor",13,126,0,*((ulonglong *) at_pencolor)},
+{"pendown",13,126,0,*((ulonglong *) at_pendown)},
+{"penup",13,126,0,*((ulonglong *) at_penup)},
 {"perimeter",13,9,0,*((ulonglong *) at_perimeter)},
 {"perimeterat",13,9,0,*((ulonglong *) at_perimeterat)| 1},
 {"perimeteratraw",13,9,0,*((ulonglong *) at_perimeteratraw)},
+{"periodic",13,9,0,*((ulonglong *) at_periodic)},
 {"perm",13,9,0,*((ulonglong *) at_perm)},
 {"perminv",13,9,0,*((ulonglong *) at_perminv)},
 {"permu2cycles",13,9,0,*((ulonglong *) at_permu2cycles)},
@@ -1020,6 +1104,7 @@
 {"plotimplicit",13,9,0,*((ulonglong *) at_plotimplicit)},
 {"plotinequation",13,9,0,*((ulonglong *) at_plotinequation)| 1},
 {"plotlist",13,9,0,*((ulonglong *) at_plotlist)},
+{"plotmatrix",13,9,0,*((ulonglong *) at_plotmatrix)| 1},
 {"plotode",13,9,0,*((ulonglong *) at_plotode)},
 {"plotparam",13,9,0,*((ulonglong *) at_plotparam)| 1},
 {"plotpolar",13,9,0,*((ulonglong *) at_plotpolar)| 1},
@@ -1030,10 +1115,11 @@
 {"point",13,9,0,*((ulonglong *) at_point)},
 {"point2d",13,9,0,*((ulonglong *) at_point2d)| 1},
 {"point3d",13,9,0,*((ulonglong *) at_point3d)| 1},
-{"pointer",13,-124,0,*((ulonglong *) at_pointer)},
+{"pointer",13,9,0,*((ulonglong *) at_pointer)},
 {"poisson",13,9,0,*((ulonglong *) at_poisson)},
 {"poisson_cdf",13,9,0,*((ulonglong *) at_poisson_cdf)},
 {"poisson_icdf",13,9,0,*((ulonglong *) at_poisson_icdf)},
+{"poisson_window",13,9,0,*((ulonglong *) at_poisson_window)},
 {"polar",13,9,0,*((ulonglong *) at_polar)},
 {"polar2rectangular",13,9,0,*((ulonglong *) at_polar2rectangular)},
 {"polar_coordinates",13,9,0,*((ulonglong *) at_polar_coordinates)},
@@ -1050,6 +1136,7 @@
 {"polyhedron",13,9,0,*((ulonglong *) at_polyhedron)},
 {"polynomial_regression",13,9,0,*((ulonglong *) at_polynomial_regression)},
 {"polynomial_regression_plot",13,9,0,*((ulonglong *) at_polynomial_regression_plot)},
+{"pop",13,9,0,*((ulonglong *) at_pop)},
 {"position",13,126,0,*((ulonglong *) at_position)},
 {"poslbdLMQ",13,9,0,*((ulonglong *) at_poslbdLMQ)},
 {"posubLMQ",13,9,0,*((ulonglong *) at_posubLMQ)},
@@ -1068,6 +1155,7 @@
 {"prevprime",13,9,0,*((ulonglong *) at_prevprime)},
 {"primpart",13,9,0,*((ulonglong *) at_primpart)},
 {"print",13,9,0,*((ulonglong *) at_print)| 1},
+{"printf",13,9,0,*((ulonglong *) at_printf)},
 {"printpow",13,9,0,*((ulonglong *) at_printpow)},
 {"prism",13,9,0,*((ulonglong *) at_prism)},
 {"product",13,9,0,*((ulonglong *) at_product)| 1},
@@ -1080,6 +1168,9 @@
 {"ptayl",13,9,0,*((ulonglong *) at_ptayl)},
 {"pwd",13,9,0,*((ulonglong *) at_pwd)},
 {"pyramid",13,9,0,*((ulonglong *) at_pyramid)},
+{"python",13,9,0,*((ulonglong *) at_python)| 1},
+{"python_compat",13,9,0,*((ulonglong *) at_python_compat)},
+{"python_list",13,9,0,*((ulonglong *) at_python_list)},
 {"q2a",13,9,0,*((ulonglong *) at_q2a)},
 {"qr",13,9,0,*((ulonglong *) at_qr)},
 {"quadric",13,9,0,*((ulonglong *) at_quadric)},
@@ -1108,16 +1199,20 @@
 {"randfisher",13,9,0,*((ulonglong *) at_randfisher)},
 {"randfisherd",13,9,0,*((ulonglong *) at_randfisherd)},
 {"randgeometric",13,9,0,*((ulonglong *) at_randgeometric)},
+{"randint",13,9,0,*((ulonglong *) at_randint)},
 {"randmarkov",13,9,0,*((ulonglong *) at_randmarkov)},
 {"randmatrix",13,9,0,*((ulonglong *) at_randmatrix)},
 {"randmultinomial",13,9,0,*((ulonglong *) at_randmultinomial)},
 {"randnormald",13,9,0,*((ulonglong *) at_randnormald)},
+{"random",13,9,0,*((ulonglong *) at_random)},
 {"randperm",13,9,0,*((ulonglong *) at_randperm)},
 {"randpoisson",13,9,0,*((ulonglong *) at_randpoisson)},
 {"randpoly",13,9,0,*((ulonglong *) at_randpoly)},
+{"randrange",13,9,0,*((ulonglong *) at_randrange)},
 {"randstudent",13,9,0,*((ulonglong *) at_randstudent)},
 {"randstudentd",13,9,0,*((ulonglong *) at_randstudentd)},
 {"randvector",13,9,0,*((ulonglong *) at_randvector)},
+{"range",13,9,0,*((ulonglong *) at_range)},
 {"rank",13,9,0,*((ulonglong *) at_rank)},
 {"ranm",13,9,0,*((ulonglong *) at_ranm)},
 {"ranv",13,9,0,*((ulonglong *) at_ranv)},
@@ -1142,7 +1237,7 @@
 {"rectangular_coordinates",13,9,0,*((ulonglong *) at_rectangular_coordinates)},
 {"recule",13,126,0,*((ulonglong *) at_recule)},
 {"red",13,2,0,*((ulonglong *) at_red)},
-{"redim",13,-124,0,*((ulonglong *) at_redim)| 1},
+{"redim",13,9,0,*((ulonglong *) at_redim)| 1},
 {"reduced_conic",13,9,0,*((ulonglong *) at_reduced_conic)},
 {"reduced_quadric",13,9,0,*((ulonglong *) at_reduced_quadric)},
 {"ref",13,9,0,*((ulonglong *) at_ref)},
@@ -1154,7 +1249,7 @@
 {"remove_language",13,9,0,*((ulonglong *) at_remove_language)},
 {"reorder",13,9,0,*((ulonglong *) at_reorder)},
 {"repete",13,77,0,*((ulonglong *) at_repete)| 1},
-{"replace",13,-124,0,*((ulonglong *) at_replace)| 1},
+{"replace",13,9,0,*((ulonglong *) at_replace)| 1},
 {"reset_solve_counter",13,9,0,*((ulonglong *) at_reset_solve_counter)},
 {"residue",13,9,0,*((ulonglong *) at_residue)},
 {"resoudre",13,9,0,*((ulonglong *) at_resoudre)| 1},
@@ -1164,11 +1259,13 @@
 {"restart_modes",13,77,0,*((ulonglong *) at_restart_modes)},
 {"restart_vars",13,77,0,*((ulonglong *) at_restart_vars)},
 {"resultant",13,9,0,*((ulonglong *) at_resultant)},
+{"reverse",13,9,0,*((ulonglong *) at_reverse)},
 {"reverse_rsolve",13,9,0,*((ulonglong *) at_reverse_rsolve)},
 {"revert",13,9,0,*((ulonglong *) at_revert)},
 {"revlist",13,9,0,*((ulonglong *) at_revlist)},
 {"rhombus",13,9,0,*((ulonglong *) at_rhombus)| 1},
 {"rhs",13,9,0,*((ulonglong *) at_rhs)},
+{"riemann_window",13,9,0,*((ulonglong *) at_riemann_window)},
 {"right",13,9,0,*((ulonglong *) at_right)},
 {"right_triangle",13,9,0,*((ulonglong *) at_right_triangle)| 1},
 {"risch",13,9,0,*((ulonglong *) at_risch)},
@@ -1196,16 +1293,18 @@
 {"rpn",13,9,0,*((ulonglong *) at_rpn)},
 {"rref",13,9,0,*((ulonglong *) at_rref)},
 {"rsolve",13,9,0,*((ulonglong *) at_rsolve)| 1},
+{"sample",13,9,0,*((ulonglong *) at_sample)},
 {"saute",13,126,0,*((ulonglong *) at_saute)},
 {"sauve",13,126,0,*((ulonglong *) at_sauve)| 1},
 {"save_history",13,9,0,*((ulonglong *) at_save_history)},
 {"scalarProduct",13,9,0,*((ulonglong *) at_scalarProduct)},
 {"scalar_product",13,9,0,*((ulonglong *) at_scalar_product)},
-{"scale",13,-124,0,*((ulonglong *) at_scale)| 1},
-{"scaleadd",13,-124,0,*((ulonglong *) at_scaleadd)| 1},
+{"scale",13,9,0,*((ulonglong *) at_scale)| 1},
+{"scaleadd",13,9,0,*((ulonglong *) at_scaleadd)| 1},
 {"scatterplot",13,9,0,*((ulonglong *) at_scatterplot)},
 {"schur",13,9,0,*((ulonglong *) at_schur)},
 {"sec",13,9,0,*((ulonglong *) at_sec)},
+{"sech",13,9,0,*((ulonglong *) at_sech)},
 {"segment",13,9,0,*((ulonglong *) at_segment)},
 {"select",13,9,0,*((ulonglong *) at_select)},
 {"semi_augment",13,9,0,*((ulonglong *) at_semi_augment)},
@@ -1214,9 +1313,14 @@
 {"seqsolve",13,9,0,*((ulonglong *) at_seqsolve)| 1},
 {"series",13,9,0,*((ulonglong *) at_series)},
 {"set_language",13,9,0,*((ulonglong *) at_set_language)},
+{"set_pixel",13,9,0,*((ulonglong *) at_set_pixel)},
 {"shift",13,9,0,*((ulonglong *) at_shift)},
 {"shift_phase",13,9,0,*((ulonglong *) at_shift_phase)},
+{"show",13,9,0,*((ulonglong *) at_show)},
 {"show_language",13,9,0,*((ulonglong *) at_show_language)},
+{"show_pixels",13,9,0,*((ulonglong *) at_show_pixels)},
+{"showturtle",13,9,0,*((ulonglong *) at_showturtle)},
+{"shuffle",13,9,0,*((ulonglong *) at_shuffle)},
 {"si",13,46,0,*((ulonglong *) at_si)| 1},
 {"sialorssinon",13,51,0,*((ulonglong *) at_sialorssinon)| 1},
 {"sign",13,9,0,*((ulonglong *) at_sign)},
@@ -1237,9 +1341,11 @@
 {"sinon",13,50,0,*((ulonglong *) at_sinon)| 1},
 {"size",13,9,0,*((ulonglong *) at_size)},
 {"sizes",13,9,0,*((ulonglong *) at_sizes)},
+{"skip",13,126,0,*((ulonglong *) at_skip)},
 {"slope",13,9,0,*((ulonglong *) at_slope)},
 {"slopeat",13,9,0,*((ulonglong *) at_slopeat)| 1},
 {"slopeatraw",13,9,0,*((ulonglong *) at_slopeatraw)},
+{"smith",13,9,0,*((ulonglong *) at_smith)},
 {"smod",13,9,0,*((ulonglong *) at_smod)},
 {"snedecor",13,9,0,*((ulonglong *) at_snedecor)},
 {"snedecor_cdf",13,9,0,*((ulonglong *) at_snedecor_cdf)},
@@ -1254,6 +1360,7 @@
 {"sort",13,9,0,*((ulonglong *) at_sort)},
 {"sorta",13,9,0,*((ulonglong *) at_sorta)},
 {"sortd",13,9,0,*((ulonglong *) at_sortd)},
+{"sorted",13,9,0,*((ulonglong *) at_sorted)},
 {"soundsec",13,9,0,*((ulonglong *) at_soundsec)},
 {"sphere",13,9,0,*((ulonglong *) at_sphere)},
 {"spherical2rectangular",13,9,0,*((ulonglong *) at_spherical2rectangular)},
@@ -1273,8 +1380,10 @@
 {"stddevp",13,9,0,*((ulonglong *) at_stddevp)},
 {"step_infolevel",13,9,0,*((ulonglong *) at_step_infolevel)},
 {"sto",13,9,0,*((ulonglong *) at_sto)},
+{"str",13,9,0,*((ulonglong *) at_str)},
 {"strassen_limit",13,9,0,*((ulonglong *) at_strassen_limit)},
 {"string",13,9,0,*((ulonglong *) at_string)},
+{"strip",13,9,0,*((ulonglong *) at_strip)},
 {"student",13,9,0,*((ulonglong *) at_student)},
 {"student_cdf",13,9,0,*((ulonglong *) at_student_cdf)},
 {"student_icdf",13,9,0,*((ulonglong *) at_student_icdf)},
@@ -1308,6 +1417,7 @@
 {"table",13,9,0,*((ulonglong *) at_table)},
 {"tablefunc",13,9,0,*((ulonglong *) at_tablefunc)},
 {"tableseq",13,9,0,*((ulonglong *) at_tableseq)| 1},
+{"tabvar",13,9,0,*((ulonglong *) at_tabvar)},
 {"tail",13,9,0,*((ulonglong *) at_tail)},
 {"tan",13,9,0,*((ulonglong *) at_tan)},
 {"tan2cossin2",13,9,0,*((ulonglong *) at_tan2cossin2)},
@@ -1325,17 +1435,20 @@
 {"tcollect",13,9,0,*((ulonglong *) at_tcollect)},
 {"tcollectsin",13,9,0,*((ulonglong *) at_tcollectsin)},
 {"testfunc",13,9,0,*((ulonglong *) at_testfunc)},
-{"tests",13,-124,0,*((ulonglong *) at_tests)},
+{"tests",13,9,0,*((ulonglong *) at_tests)},
 {"tetrahedron",13,9,0,*((ulonglong *) at_tetrahedron)},
 {"texpand",13,9,0,*((ulonglong *) at_texpand)},
 {"textinput",13,9,0,*((ulonglong *) at_textinput)| 1},
+{"thiele",13,9,0,*((ulonglong *) at_thiele)},
 {"threads_allowed",13,9,0,*((ulonglong *) at_threads_allowed)},
+{"threshold",13,9,0,*((ulonglong *) at_threshold)},
 {"throw",13,77,0,*((ulonglong *) at_throw)},
 {"time",13,9,0,*((ulonglong *) at_time)| 1},
 {"tlin",13,9,0,*((ulonglong *) at_tlin)},
 {"total_degree",13,9,0,*((ulonglong *) at_total_degree)},
 {"tourne_droite",13,126,0,*((ulonglong *) at_tourne_droite)},
 {"tourne_gauche",13,126,0,*((ulonglong *) at_tourne_gauche)},
+{"tpsolve",13,9,0,*((ulonglong *) at_tpsolve)},
 {"trace",13,9,0,*((ulonglong *) at_trace)},
 {"tran",13,9,0,*((ulonglong *) at_tran)},
 {"translation",13,9,0,*((ulonglong *) at_translation)},
@@ -1343,15 +1456,19 @@
 {"triangle",13,9,0,*((ulonglong *) at_triangle)},
 {"triangle_paper",13,9,0,*((ulonglong *) at_triangle_paper)},
 {"triangle_plein",13,126,0,*((ulonglong *) at_triangle_plein)},
+{"triangle_window",13,9,0,*((ulonglong *) at_triangle_window)},
 {"trig2exp",13,9,0,*((ulonglong *) at_trig2exp)},
 {"trigcos",13,9,0,*((ulonglong *) at_trigcos)},
 {"trigexpand",13,9,0,*((ulonglong *) at_trigexpand)},
+{"triginterp",13,9,0,*((ulonglong *) at_triginterp)},
+{"trigsimplify",13,9,0,*((ulonglong *) at_trigsimplify)},
 {"trigsin",13,9,0,*((ulonglong *) at_trigsin)},
 {"trigtan",13,9,0,*((ulonglong *) at_trigtan)},
 {"trn",13,9,0,*((ulonglong *) at_trn)},
 {"trunc",13,9,0,*((ulonglong *) at_trunc)},
 {"truncate",13,9,0,*((ulonglong *) at_truncate)},
 {"tsimplify",13,9,0,*((ulonglong *) at_tsimplify)},
+{"tukey_window",13,9,0,*((ulonglong *) at_tukey_window)},
 {"turtle_stack",13,126,0,*((ulonglong *) at_turtle_stack)},
 {"type",13,9,0,*((ulonglong *) at_type)},
 {"ufactor",13,9,0,*((ulonglong *) at_ufactor)},
@@ -1367,6 +1484,7 @@
 {"uniformd_icdf",13,9,0,*((ulonglong *) at_uniformd_icdf)},
 {"unitV",13,9,0,*((ulonglong *) at_unitV)},
 {"unquote",13,9,0,*((ulonglong *) at_unquote)},
+{"upper",13,9,0,*((ulonglong *) at_upper)},
 {"usimplify",13,9,0,*((ulonglong *) at_usimplify)},
 {"valuation",13,9,0,*((ulonglong *) at_valuation)},
 {"vandermonde",13,9,0,*((ulonglong *) at_vandermonde)},
@@ -1378,6 +1496,7 @@
 {"vertices_abc",13,9,0,*((ulonglong *) at_vertices_abc)},
 {"vertices_abca",13,9,0,*((ulonglong *) at_vertices_abca)},
 {"vpotential",13,9,0,*((ulonglong *) at_vpotential)| 1},
+{"warn_equal_in_prog",13,9,0,*((ulonglong *) at_warn_equal_in_prog)},
 {"watch",13,9,0,*((ulonglong *) at_watch)| 1},
 {"weibull",13,9,0,*((ulonglong *) at_weibull)},
 {"weibull_cdf",13,9,0,*((ulonglong *) at_weibull_cdf)},
@@ -1385,6 +1504,7 @@
 {"weibulld",13,9,0,*((ulonglong *) at_weibulld)},
 {"weibulld_cdf",13,9,0,*((ulonglong *) at_weibulld_cdf)},
 {"weibulld_icdf",13,9,0,*((ulonglong *) at_weibulld_icdf)},
+{"welch_window",13,9,0,*((ulonglong *) at_welch_window)},
 {"whattype",13,9,0,*((ulonglong *) at_whattype)},
 {"when",13,9,0,*((ulonglong *) at_when)| 1},
 {"white",13,2,0,*((ulonglong *) at_white)},
@@ -1396,6 +1516,8 @@
 {"write",13,9,0,*((ulonglong *) at_write)| 1},
 {"writergb",13,9,0,*((ulonglong *) at_writergb)},
 {"writewav",13,9,0,*((ulonglong *) at_writewav)},
+{"wz_certificate",13,9,0,*((ulonglong *) at_wz_certificate)| 1},
+{"xcas",13,9,0,*((ulonglong *) at_xcas)| 1},
 {"xcas_mode",13,9,0,*((ulonglong *) at_xcas_mode)},
 {"xyztrange",13,9,0,*((ulonglong *) at_xyztrange)},
 {"yellow",13,2,0,*((ulonglong *) at_yellow)},
@@ -1407,5 +1529,5 @@
 {"Σ",13,-124,0,*((ulonglong *) at_HPSUM)| 1},
 {"ΣLIST",13,-124,0,*((ulonglong *) at_SIGMALIST)},
 {"∂",13,-124,0,*((ulonglong *) at_HPDIFF)| 1},
-{"∡",13,22,0,*((ulonglong *) at_∡)},
+{"∡",13,22,0,*((ulonglong *) at_polar_complex)},
 {"∫",13,-124,0,*((ulonglong *) at_HPINT)| 1}
